<?php

namespace Drupal\amazon_pa_filter\Plugin\Filter;

use Drupal\filter\Plugin\FilterBase;
use Drupal\filter\FilterProcessResult;
use Drupal\Core\Form\FormStateInterface;

/**
 * @Filter(
 *   id = "amazon",
 *   title = @Translation("Amazon filter"),
 *   description = @Translation("Provides access to many types of Amazon data. Simplest usage: [amazon:ASIN:inline], for example [amazon:0596515804:inline]."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_MARKUP_LANGUAGE,
 * )
 */

class AmazonFilter extends FilterBase {

  /**
   * process the filter
   *
   * @param string $text
   * @param string $langcode
   *
   * @return \Drupal\filter\FilterProcessResult
   */

  public function process($text, $langcode) {

    $pattern = "@\[amazon(?: |:|%20)+(.*?)(?:(?: |:|%20)(.*?))?\]@";
    $matches = array();
    if (preg_match_all($pattern, $text, $matches)) {
      $search = $matches[0];
      $replace = array();

      //MULTIPLE ASINS in one request. Solo triggers throtteling....VERY fast if multiple tokens on one page
      //if someone overuses tokens on a page..then we need to raise the random sleep
      //that may be a problem in php timeout and is not really great
      //no other way if you are new and only get 1 request per second.
      $asin_list = array();
      $asin_count = 0;
      $items = array();

      //all asisn to an array, max 10, then request to amazonapi
      //if more than 10, request then merge, then loop again until finish
      foreach ($matches[0] as $key => $value) {
        if($asin_count <= 9) {
          $asin_list[$key] = $matches[1][$key];
          $asin_count++;
        }
        else {
          $items = amazon_pa_item_lookup($asin_list) + $items;
          $asin_count = 0;
        }
      }
      $items = amazon_pa_item_lookup($asin_list) + $items;

      $processed_asisn = array();

      //put back in the data for duplicate asins
      $items_results = $items;
      $items = array();
      foreach ($asin_list as $key => $asin) {
        $items[] = $items_results[$asin];
      }

      foreach ($items as $ikey => $item) {
        $asin = $item['asin'];
        $processed_asisn[] = $asin;
        //get the key for this asin entry in matches
        //$action_key = array_search($asin, $matches[1]);
        $action = $matches[2][$ikey];
        //$items = amazon_item_lookup($asin);


        switch ($action) {
          case "":
          case 'inline':
          $image_ = [
            '#theme' => 'amazon_pa_item',
            '#item' => $item,
          ];
          $replace[] = \Drupal::service('renderer')->render($image_);
          break;

          // Full is a synonym of 'details'.
          case 'full':
          case 'details':
          $image_ = [
            '#theme' => 'amazon_details',
            '#item' => $item,
          ];
          $replace[] = \Drupal::service('renderer')->render($image_);
          break;

          // Handle themeable cases, like thumbnail.
          case 'thumbnail':
            $image_ = [
              '#theme' => 'amazon_item_thumbnail_medium',
              '#item' => $item,
            ];
            $replace[] = \Drupal::service('renderer')->render($image_);
            break;

          default:
            // Allow to use anything found in the item array. Like title, asin, detailpageurl $action contains the variable name
            $image_ = [
              '#theme' => 'amazon_detail',
              '#item' => $item,
              '#detail' => $action
            ];
            //$replace[] = $image_;
            $replace[] = \Drupal::service('renderer')->render($image_);
            break;
        }
      }

      //asins where we have no results or invalid must be marked
      // error case
      foreach ($asin_list as $asin) {
        if(!in_array($asin, $processed_asisn)) {
          $replace[] = "<!-- The Amazon product '$asin' could not be found.-->";
        }
      }

      $text = str_replace($search, $replace, $text);

    }

    return new FilterProcessResult($text);
  }

  public function settingsForm(array $form, FormStateInterface $form_state) {
    //not needed
    return $form;
  }




}
